==> httpcomponents-client_4.1.1.orig.tar.gz: httpcomponents-client-4.1.1/httpclient-cache/src/test/java/org/apache/http/impl/client/cache/RequestEquivalent.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.http.impl.client.cache;

import org.apache.http.HttpRequest;
import org.easymock.IArgumentMatcher;

public class RequestEquivalent implements IArgumentMatcher {

    private HttpRequest expected;

    public RequestEquivalent(HttpRequest expected) {
        this.expected = expected;
    }

    public boolean matches(Object actual) {
        if (!(actual instanceof HttpRequest))
            return false;
        HttpRequest other = (HttpRequest) actual;
        return HttpTestUtils.equivalent(expected, other);
    }

    public void appendTo(StringBuffer buf) {
        buf.append("eqRequest(");
        buf.append(expected);
        buf.append(")");
    }

}

==> httpcomponents-client_4.3.3.orig.tar.gz: httpcomponents-client-4.3.3/httpclient-cache/src/test/java/org/apache/http/impl/client/cache/RequestEquivalent.java <==
/*
 * ====================================================================
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 *
 */
package org.apache.http.impl.client.cache;

import org.apache.http.HttpRequest;
import org.easymock.IArgumentMatcher;

public class RequestEquivalent implements IArgumentMatcher {

    private final HttpRequest expected;

    public RequestEquivalent(final HttpRequest expected) {
        this.expected = expected;
    }

    public boolean matches(final Object actual) {
        if (!(actual instanceof HttpRequest)) {
            return false;
        }
        final HttpRequest other = (HttpRequest) actual;
        return HttpTestUtils.equivalent(expected, other);
    }

    public void appendTo(final StringBuffer buf) {
        buf.append("eqRequest(");
        buf.append(expected);
        buf.append(")");
    }

}
